Coverage for /home/tribaal/workspace/django-shop/shop/urls/checkout: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/urls/checkout : 100.00%

## 3 statements 3 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 | from django.conf.urls.defaults import url, patterns from shop.views.checkout import ( # SelectPaymentView, # SelectShippingView, CheckoutSelectionView, PaymentBackendRedirectView, ShippingBackendRedirectView, ThankYouView, ) urlpatterns = patterns('', url(r'^$', CheckoutSelectionView.as_view(), name='checkout_selection' # First step of the checkout process ), #url(r'^checkout/ship/$', SelectShippingView.as_view(), # name='checkout_shipping' # First step of the checkout process # ), url(r'^ship/$', ShippingBackendRedirectView.as_view(), name='checkout_shipping' # First step of the checkout process ), #url(r'^checkout/pay/$', SelectPaymentView.as_view(), # name='checkout_payment' # Second step of the checkout process # ), url(r'^pay/$', PaymentBackendRedirectView.as_view(), name='checkout_payment' # First step of the checkout process ), url(r'^thank_you/$', ThankYouView.as_view(), name='thank_you_for_your_order' # Second step of the checkout process ), )